==> sources_fancymenu_fabric_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/customization/listener/listeners/OnEntityDiedListener.java <==
package de.keksuccino.fancymenu.customization.listener.listeners;

import de.keksuccino.fancymenu.customization.listener.AbstractListener;
import de.keksuccino.fancymenu.util.LocalizationUtils;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.UUID;
import net.minecraft.class_243;
import net.minecraft.class_2561;
import net.minecraft.class_310;

public class OnEntityDiedListener extends AbstractListener {

    @Nullable
    private String cachedEntityKey;
    @Nullable
    private String cachedDistanceToPlayer;
    @Nullable
    private String cachedDeathPosX;
    @Nullable
    private String cachedDeathPosY;
    @Nullable
    private String cachedDeathPosZ;
    @Nullable
    private String cachedEntityUuid;
    @Nullable
    private String cachedDimensionKey;
    private boolean isSameDimensionAsPlayer;
    @Nullable
    private String cachedDamageType;
    @Nullable
    private String cachedKillerName;
    @Nullable
    private String cachedKillerKey;
    @Nullable
    private String cachedKillerUuid;

    public OnEntityDiedListener() {
        super("entity_died");
    }

    public void onEntityDied(@Nullable String entityKey, @Nullable UUID entityUuid, double posX, double posY, double posZ, @Nullable String levelKey, @Nullable String killerName, @Nullable String killerKey, @Nullable String killerUuid, @Nullable String damageType) {
        this.cachedEntityKey = entityKey;
        this.cachedEntityUuid = (entityUuid != null) ? entityUuid.toString() : null;
        this.cachedDeathPosX = Double.toString(posX);
        this.cachedDeathPosY = Double.toString(posY);
        this.cachedDeathPosZ = Double.toString(posZ);
        this.cachedDimensionKey = levelKey;
        this.cachedDistanceToPlayer = this.computeDistanceToPlayer(posX, posY, posZ, levelKey);
        this.cachedDamageType = (damageType != null && !damageType.isBlank()) ? damageType : null;
        this.cachedKillerName = (killerName != null && !killerName.isBlank()) ? killerName : null;
        this.cachedKillerKey = (killerKey != null && !killerKey.isBlank()) ? killerKey : null;
        this.cachedKillerUuid = (killerUuid != null && !killerUuid.isBlank()) ? killerUuid : null;
        this.notifyAllInstances();
    }

    @Nullable
    private String computeDistanceToPlayer(double posX, double posY, double posZ, @Nullable String levelKey) {
        class_310 minecraft = class_310.method_1551();
        if (minecraft.field_1724 == null) {
            this.isSameDimensionAsPlayer = false;
            return null;
        }
        String playerLevelKey = minecraft.field_1724.field_6002 != null ? minecraft.field_1724.field_6002.method_27983().method_29177().toString() : null;
        boolean sameDimension = (levelKey != null && playerLevelKey != null && playerLevelKey.equals(levelKey)) || (levelKey == null && playerLevelKey == null);
        this.isSameDimensionAsPlayer = sameDimension;
        if (!sameDimension) {
            return "-1";
        }
        class_243 playerPos = minecraft.field_1724.method_19538();
        double distance = playerPos.method_1022(new class_243(posX, posY, posZ));
        if (Double.isFinite(distance)) {
            return Double.toString(distance);
        }
        return null;
    }

    @Override
    protected void buildCustomVariablesAndAddToList(List<CustomVariable> list) {
        list.add(new CustomVariable("entity_key", () -> this.cachedEntityKey != null ? this.cachedEntityKey : "ERROR"));
        list.add(new CustomVariable("distance_to_player", () -> this.cachedDistanceToPlayer != null ? this.cachedDistanceToPlayer : "0"));
        list.add(new CustomVariable("death_pos_x", () -> this.cachedDeathPosX != null ? this.cachedDeathPosX : "0"));
        list.add(new CustomVariable("death_pos_y", () -> this.cachedDeathPosY != null ? this.cachedDeathPosY : "0"));
        list.add(new CustomVariable("death_pos_z", () -> this.cachedDeathPosZ != null ? this.cachedDeathPosZ : "0"));
        list.add(new CustomVariable("entity_uuid", () -> this.cachedEntityUuid != null ? this.cachedEntityUuid : "ERROR"));
        list.add(new CustomVariable("dimension_key", () -> this.cachedDimensionKey != null ? this.cachedDimensionKey : "UNKNOWN"));
        list.add(new CustomVariable("damage_type", () -> this.cachedDamageType != null ? this.cachedDamageType : "UNKNOWN"));
        list.add(new CustomVariable("is_same_dimension_as_player", () -> Boolean.toString(this.isSameDimensionAsPlayer)));
        list.add(new CustomVariable("entity_killed_by_name", () -> this.cachedKillerName != null ? this.cachedKillerName : "NONE"));
        list.add(new CustomVariable("entity_killed_by_key", () -> this.cachedKillerKey != null ? this.cachedKillerKey : "NONE"));
        list.add(new CustomVariable("entity_killed_by_uuid", () -> this.cachedKillerUuid != null ? this.cachedKillerUuid : "NONE"));
    }

    @Override
    public @NotNull class_2561 getDisplayName() {
        return class_2561.method_43471("fancymenu.listeners.on_entity_died");
    }

    @Override
    public @NotNull List<class_2561> getDescription() {
        return List.of(LocalizationUtils.splitLocalizedLines("fancymenu.listeners.on_entity_died.desc"));
    }
}

==> sources_fancymenu_fabric_3.8.1_MC_1.21.10.jar: de/keksuccino/fancymenu/customization/listener/listeners/OnEntityDiedListener.java <==
package de.keksuccino.fancymenu.customization.listener.listeners;

import de.keksuccino.fancymenu.customization.listener.AbstractListener;
import de.keksuccino.fancymenu.util.LocalizationUtils;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.UUID;
import net.minecraft.class_243;
import net.minecraft.class_2561;
import net.minecraft.class_310;

public class OnEntityDiedListener extends AbstractListener {

    @Nullable
    private String cachedEntityKey;
    @Nullable
    private String cachedDistanceToPlayer;
    @Nullable
    private String cachedDeathPosX;
    @Nullable
    private String cachedDeathPosY;
    @Nullable
    private String cachedDeathPosZ;
    @Nullable
    private String cachedEntityUuid;
    @Nullable
    private String cachedDimensionKey;
    private boolean isSameDimensionAsPlayer;
    @Nullable
    private String cachedDamageType;
    @Nullable
    private String cachedKillerName;
    @Nullable
    private String cachedKillerKey;
    @Nullable
    private String cachedKillerUuid;

    public OnEntityDiedListener() {
        super("entity_died");
    }

    public void onEntityDied(@Nullable String entityKey, @Nullable UUID entityUuid, double posX, double posY, double posZ, @Nullable String levelKey, @Nullable String killerName, @Nullable String killerKey, @Nullable String killerUuid, @Nullable String damageType) {
        this.cachedEntityKey = entityKey;
        this.cachedEntityUuid = (entityUuid != null) ? entityUuid.toString() : null;
        this.cachedDeathPosX = Double.toString(posX);
        this.cachedDeathPosY = Double.toString(posY);
        this.cachedDeathPosZ = Double.toString(posZ);
        this.cachedDimensionKey = levelKey;
        this.cachedDistanceToPlayer = this.computeDistanceToPlayer(posX, posY, posZ, levelKey);
        this.cachedDamageType = (damageType != null && !damageType.isBlank()) ? damageType : null;
        this.cachedKillerName = (killerName != null && !killerName.isBlank()) ? killerName : null;
        this.cachedKillerKey = (killerKey != null && !killerKey.isBlank()) ? killerKey : null;
        this.cachedKillerUuid = (killerUuid != null && !killerUuid.isBlank()) ? killerUuid : null;
        this.notifyAllInstances();
    }

    @Nullable
    private String computeDistanceToPlayer(double posX, double posY, double posZ, @Nullable String levelKey) {
        class_310 minecraft = class_310.method_1551();
        if (minecraft.field_1724 == null) {
            this.isSameDimensionAsPlayer = false;
            return null;
        }
        String playerLevelKey = minecraft.field_1724.method_73183() != null ? minecraft.field_1724.method_73183().method_27983().method_29177().toString() : null;
        boolean sameDimension = (levelKey != null && playerLevelKey != null && playerLevelKey.equals(levelKey)) || (levelKey == null && playerLevelKey == null);
        this.isSameDimensionAsPlayer = sameDimension;
        if (!sameDimension) {
            return "-1";
        }
        class_243 playerPos = minecraft.field_1724.method_73189();
        double distance = playerPos.method_1022(new class_243(posX, posY, posZ));
        if (Double.isFinite(distance)) {
            return Double.toString(distance);
        }
        return null;
    }

    @Override
    protected void buildCustomVariablesAndAddToList(List<CustomVariable> list) {
        list.add(new CustomVariable("entity_key", () -> this.cachedEntityKey != null ? this.cachedEntityKey : "ERROR"));
        list.add(new CustomVariable("distance_to_player", () -> this.cachedDistanceToPlayer != null ? this.cachedDistanceToPlayer : "0"));
        list.add(new CustomVariable("death_pos_x", () -> this.cachedDeathPosX != null ? this.cachedDeathPosX : "0"));
        list.add(new CustomVariable("death_pos_y", () -> this.cachedDeathPosY != null ? this.cachedDeathPosY : "0"));
        list.add(new CustomVariable("death_pos_z", () -> this.cachedDeathPosZ != null ? this.cachedDeathPosZ : "0"));
        list.add(new CustomVariable("entity_uuid", () -> this.cachedEntityUuid != null ? this.cachedEntityUuid : "ERROR"));
        list.add(new CustomVariable("dimension_key", () -> this.cachedDimensionKey != null ? this.cachedDimensionKey : "UNKNOWN"));
        list.add(new CustomVariable("damage_type", () -> this.cachedDamageType != null ? this.cachedDamageType : "UNKNOWN"));
        list.add(new CustomVariable("is_same_dimension_as_player", () -> Boolean.toString(this.isSameDimensionAsPlayer)));
        list.add(new CustomVariable("entity_killed_by_name", () -> this.cachedKillerName != null ? this.cachedKillerName : "NONE"));
        list.add(new CustomVariable("entity_killed_by_key", () -> this.cachedKillerKey != null ? this.cachedKillerKey : "NONE"));
        list.add(new CustomVariable("entity_killed_by_uuid", () -> this.cachedKillerUuid != null ? this.cachedKillerUuid : "NONE"));
    }

    @Override
    public @NotNull class_2561 getDisplayName() {
        return class_2561.method_43471("fancymenu.listeners.on_entity_died");
    }

    @Override
    public @NotNull List<class_2561> getDescription() {
        return List.of(LocalizationUtils.splitLocalizedLines("fancymenu.listeners.on_entity_died.desc"));
    }
}
